@@ -152,23 +152,24 @@ def handle_args_and_set_context(args):
   Returns:
       a populated EFPWContext object
   Raises:
-      RuntimeError: if repo or branch isn't as spec'd in ef_config.EF_REPO and ef_config.EF_REPO_BRANCH
+      RuntimeError: if branch isn't as spec'd in ef_config.EF_REPO_BRANCH
       ValueError: if a parameter is invalid
   """
-  parser = argparse.ArgumentParser()
+  parser = argparse.ArgumentParser(description="Encrypt/decrypt template secrets.")
   parser.add_argument("service", help="name of service password is being generated for")
   parser.add_argument("env", help=", ".join(EFConfig.ENV_LIST))
-  parser.add_argument("--length", help="length of generated password (default 32)", default=32)
-  parser.add_argument("--decrypt", help="encrypted string to be decrypted", default="")
-  parser.add_argument("--plaintext", help="secret to be encrypted rather than a randomly generated one", default="")
-  parser.add_argument("--secret_file", help="json file containing secrets to be encrypted", default="")
+  group = parser.add_mutually_exclusive_group()
+  group.add_argument("--decrypt", help="encrypted string to be decrypted", default="")
+  group.add_argument("--plaintext", help="secret to be encrypted rather than a randomly generated one", default="")
+  group.add_argument("--secret_file", help="json file containing secrets to be encrypted", default="")
   parser.add_argument("--match", help="used in conjunction with --secret_file to match against keys to be encrypted", default="")
+  parser.add_argument("--length", help="length of generated password (default 32)", default=32)
   parsed_args = vars(parser.parse_args(args))
   context = EFPWContext()
   try:
     context.env = parsed_args["env"]
   except ValueError as e:
-    ef_utils.fail("Error in env: {}".format(e.message))
+    ef_utils.fail("Error in env: {}".format(e))
   context.service = parsed_args["service"]
   context.decrypt = parsed_args["decrypt"]
   context.length = parsed_args["length"]
@@ -199,8 +200,9 @@ def main():
     return
 
   if context.decrypt:
-    decrypted_password = ef_utils.kms_decrypt(kms_client=clients['kms'], secret=context.decrypt)
-    print("Decrypted Secret: {}".format(decrypted_password))
+    decrypted = ef_utils.kms_decrypt(kms_client=clients['kms'], secret=context.decrypt)
+    key_aliases = ef_utils.kms_key_alias(clients['kms'], decrypted.key_id)
+    print("Decrypted Secret: {}; Key: {}".format(decrypted.plaintext, ', '.join(key_aliases)))
     return
 
   if context.plaintext:
